<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation>À propos de Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Remerciements</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traductions</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Version : %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga fournit une imprimante virtuelle pour CUPS. Elle peut être utilisée pour prévisualiser des impressions ou pour imprimer des livrets.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Tous droits réservés : %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Page d’accueil : %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licence : %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Si vous êtes intéressé à travailler avec notre équipe de développement, &lt;a %1&gt;rejoigniez-nous&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Remerciements particuliers à :</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Si vous désirez aider à traduire, nous serons heureux de vous accueillir dans notre équipe de traduction sur le &lt;a %1&gt;serveur Transifex&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga est développé par l’&lt;a %1&gt;équipe Boomaga et ses contributeurs&lt;/a&gt; sur GitHub.</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Divisez vos livrets longs en de plus petits, pour l’impression.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Imprimer comme sous-livrets</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Nombre maximale de feuilles dans votre sous-livret.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Feuilles dans votre sous-livret :</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Enregistrer automatiquement vos travaux lors de chaque impression</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Enregistrer automatiquement les sessions récentes</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Autoriser les marges négatives :</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Sélectionner le répertoire des travaux enregistrés</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Répertoire des travaux enregistrés :</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Imprimer vers PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Fichier de sortie :</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Métainfo</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Auteur :</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Le nom de la personne qui a créé le document.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titre :</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Objet :</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>L’objet du document.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Mots-clefs associés avec le document.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Mots-clés :</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>Fichiers PDF (*.pdf);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Écraser le fichier ?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Un fichier nommé « %1 » existe déjà.
Êtes-vous sûr de vouloir l’écraser ?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Le titre du document.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 pages</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichiers</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Mise en page</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 dans 1</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 dans 1</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Livret</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Imprimer sur les deux côtés d’une feuille.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Des deux côtés</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Travaux</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Imprimante</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Configurer...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barre d’outils</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Imprimer et fermer</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Prochaine feuille</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Feuille précédente</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>À propos de Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v de %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Imprimer toutes les pages sur %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Imprimer les pages impaires sur %1.&lt;p&gt;Une fois terminé, tourner les pages, les insérer dans l’imprimante&lt;br&gt;et cliquer sur le bouton Continue.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Imprimer les pages paires sur %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 pages</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 page</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 feuilles</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 feuille</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Feuille %1 de %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Insérer une page après avant cette page</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Effacer cette page</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Rétablir la suppression</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Insérer une page blanche avant cette page</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Enregistrer le projet</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Enregistrer sous...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Enregistrer le projet sous un nouveau nom</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Maj+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Ouvrir...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Ouvrir un projet existant</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Page %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Fichiers Boomaga (*.boo);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Projet enregistré avec succès</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Tous les fichiers pris en charge (*.pdf *.boo);;Fichiers Boomaga (*.boo);;Fichiers PDF (*.pdf);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 dans 1 horizontal</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 dans 1 vertical</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 dans 1 horizontal</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 dans 1 vertical</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Démarrer un nouveau livret à partir de cette page</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Ne pas démarrer un nouveau livret à partir de cette page</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Tourner la page vers la gauche</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Tourner la page vers la droite</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Renommer le travail</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Tourner le travail vers la gauche</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Tourner le travail vers la droite</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Titre du travail :</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Exporter le projet en PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Cloner le travail...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Cloner le travail</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Nombre de copies :</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Imprimer avec des options...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Choisir le nombre de copies avant d’imprimer.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Maj+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Sous-livrets</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Annuler la suppression de page</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Page %1 de %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Fichiers récents</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>&amp;Modifier la page</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Modifier le &amp;travail</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>&amp;Exporter en PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Supprimer cette page et les suivantes</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Supprimer le travail actuel</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Enregistrement automatique</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Je ne peux pas créer le répertoire « %1 »</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2 : page %3</translation>
    </message>
</context>
<context>
    <name>PdfMerger</name>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Imprimer le document</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Nombre de copies :</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Collationner les copies :</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Marges (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Droite :</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Bas :</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Interne :</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Gauche :</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Haut :</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Encadrer</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Imprimer en ordre inversé</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Imprimante recto-verso</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Manuel avec inversion (convient à la plupart des imprimantes)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Manuel sans inversion</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Préférences de &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Profils</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Réinitialiser à la valeur par défaut</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Profil %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Mode chromatique :</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Forcer l’échelle de gris</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Forcer la couleur</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Imprimer sur les deux côtés</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Inverser sur le bord court</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Inverser sur le bord long</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation>Je ne peux pas ouvrir le fichier « %1 » (fichier ou répertoire inexistant)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation>Je ne peux pas ouvrir le fichier « %1 » (accès refusé)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Je ne peux pas lire le fichier « %1 ». Soit ce n’est pas un type de fichier pris en charge, soit le fichier est endommagé.</translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Je ne peux pas ouvrir le fichier « %1 »</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Je ne peux pas lire le fichier « %1 »</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Valeur par défaut</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Sansnom.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Sous-livret %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 pages</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Je ne peux pas créer le fichier temporaire « %1 »</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation>Quelque chose ne va pas. Je ne peux pas trouver le programme boomagamerger.
Veuillez me réinstaller.</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Je ne peux pas lire le fichier « %1 »</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Je ne peux pas écrire le fichier « %1 »</translation>
    </message>
</context>
</TS>